@@ -17,7 +17,7 @@
 
 import sys, os, jinja2, yaml, argparse, re, copy, getpass, traceback
 
-__version__ = '1.7.2'
+__version__ = '1.8.0'
 jinja2_filters = []
 
 def import_filters(errc = 0):
@@ -372,6 +372,7 @@ class JinjaFx():
             n = len(self.__g_datarows[0])
             fields = [list(map(self.__jfx_expand, fields[:n] + [''] * (n - len(fields)), [True] * n))]
 
+            # recm = r'(?<!\\){[ \t]*([0-9]+):([0-9]+)[ \t]*(?<!\\)}' # TODO: REMOVE PAD
             recm = r'(?<!\\){[ \t]*([0-9]+):([0-9]+)(?::([0-9]+))?[ \t]*(?<!\\)}'
 
             row = 0
@@ -406,7 +407,18 @@ class JinjaFx():
 
                 for col in range(1, len(fields[row])):
                   fields[row][col] = re.sub(r'\\([0-9]+)', lambda m: groups.get(int(m.group(1)), '\\' + m.group(1)), fields[row][col][0])
-                  fields[row][col] = re.sub(r'\\([}{])', r'\1', fields[row][col])
+
+                  delta = 0
+                  for m in re.finditer(r'([0-9]+)(?<!\\)\%([0-9]+)', fields[row][col]):
+                    pvalue = str(int(m.group(1))).zfill(int(m.group(2)))
+                    fields[row][col] = fields[row][col][:m.start() + delta] + pvalue + fields[row][col][m.end() + delta:]
+
+                    if len(m.group(0)) > len(pvalue):
+                      delta -= len(m.group(0)) - len(pvalue)
+                    else:
+                      delta += len(pvalue) - len(m.group(0))
+
+                  fields[row][col] = re.sub(r'\\([}{%])', r'\1', fields[row][col])
 
                   if col in int_indices:
                     fields[row][col] = int(fields[row][col])
@@ -445,6 +457,9 @@ class JinjaFx():
     if 'jinja2_extensions' not in gvars:
       gvars.update({ 'jinja2_extensions': [] })
 
+    else:
+      sys.path.append(os.getcwd())
+
     jinja2_options = {
       'undefined': jinja2.StrictUndefined,
       'trim_blocks': True,
@@ -559,7 +574,12 @@ class JinjaFx():
   def __jfx_data_counter(self, m, orow, col, row):
     start = m.group(1)
     increment = m.group(2)
-    pad = int(m.group(3)) if m.lastindex == 3 else 0
+    pad = int(m.group(3)) if m.lastindex == 3 else 0 # TODO: REMOVE PAD
+
+    if pad > 0:
+      message = "padding on counters has been deprecated - please use the '%' pad operator instead"
+      if message not in self.__g_warnings:
+        self.__g_warnings.append(message)
 
     key = '_datacnt_r_' + str(orow) + '_' + str(col) + '_' + m.group()
 
@@ -567,6 +587,7 @@ class JinjaFx():
       n = self.__g_dict.get(key, int(start) - int(increment))
       self.__g_dict[key] = n + int(increment)
       self.__g_dict[key + '_' + str(row)] = False
+    # return str(self.__g_dict[key]) # TODO: REMOVE PAD
     return str(self.__g_dict[key]).zfill(pad)
 
 
@@ -591,6 +612,7 @@ class JinjaFx():
 
       i = 0
       while i < len(pofa):
+        # m = re.search(r'(?<!\\)\{[ \t]*([0-9]+-[0-9]+):([0-9]+)[ \t]*(?<!\\)\}', pofa[i]) # TODO: REMOVE PAD
         m = re.search(r'(?<!\\)\{[ \t]*([0-9]+-[0-9]+):([0-9]+)(?::([0-9]+))?[ \t]*(?<!\\)\}', pofa[i])
         if m:
           mpos = groups[i][0].index(m.group())
@@ -606,7 +628,13 @@ class JinjaFx():
           step = int(m.group(2)) if end > start else 0 - int(m.group(2))
 
           for n in range(start, end, step):
-            n = str(n).zfill(int(m.group(3)) if m.lastindex == 3 else 0)
+            if m.lastindex == 3:
+              message = "padding on counters has been deprecated - please use the '%' pad operator instead"
+              if message not in self.__g_warnings:
+                self.__g_warnings.append(message)
+
+            n = str(n).zfill(int(m.group(3)) if m.lastindex == 3 else 0) # TODO: REMOVE PAD
+            # pofa.append(pofa[i][:m.start(1) - 1] + str(n) + pofa[i][m.end(m.lastindex) + 1:]) # TODO: REMOVE PAD
             pofa.append(pofa[i][:m.start(1) - 1] + n + pofa[i][m.end(m.lastindex) + 1:])
 
             ngroups = list(groups[i])
